@@ -8,6 +8,8 @@ SUPPORTED_BLOCKS = [
     "paragraph",
     "bookmark",
     "code",
+    "divider",
+    "image",
 ]
 
 
@@ -40,6 +42,16 @@ def markdownify_block(block: dict) -> str:
         _, netloc, path, *_ = urlparse(_url)
         return f"[{netloc + path}]({_content['url']})\n"
 
+    if _type == "divider":
+        return "\n***\n"
+
+    if _type == "image":
+        _hosted_local = _content["type"]
+        _url = _content[_hosted_local]["url"]
+        _, netloc, path, *_ = urlparse(_url)
+        _name = path.split("/")[-1].split(".")[0]
+        return f"\n![{_name}]({_url})\n"
+
     # Text types
     _text_objs = _content.get("text", [])
     md_text = ""
